# gsi_xtab

[![ci/cd](https://github.com/gsienvironmental/gsi_xtab/actions/workflows/ci-cd.yml/badge.svg)](https://github.com/gsienvironmental/gsi_xtab/actions/workflows/ci-cd.yml)
[![Documentation Status](https://readthedocs.org/projects/pg-upsert/badge/?version=latest)](https://pg-upsert.readthedocs.io/en/latest/?badge=latest)
[![PyPI Latest Release](https://img.shields.io/pypi/v/gsi_xtab.svg)](https://pypi.org/project/gsi_xtab/)
[![PyPI Downloads](https://img.shields.io/pypi/dm/gsi_xtab.svg?label=pypi%20downloads)](https://pypi.org/project/gsi_xtab/)
[![Python Version Support](https://img.shields.io/pypi/pyversions/gsi_xtab.svg)](https://pypi.org/project/gsi_xtab/)
